# Examples

This directory contains a set of practical examples.


## Running Examples during development

If you want to run the examples during development, make sure to install benchit from the root with `pip install -e .`.
